<?php

/**
 * @file
 * Contains Rules information for ActiveCampaign.
 */  

/**
 * Implements hook_rules_event_info().
 */
function activecampaign_rules_rules_event_info() {
  $items = array(
    'activecampaign_contact_sync_event' => array(
      'label' => t('After drupal updates an ActiveCampaign contact'),
      'group' => t('ActiveCampaign'),
      'variables' => array(
        'user' => array('type' => 'user', 'label' => 'Drupal User'),
      ),
    ),
    'activecampaign_contact_updated' => array(
      'label' => t('After updating an ActiveCampaign contact (From AC End)'),
      'group' => t('ActiveCampaign'),
      'variables' => array(
        'contact' => array('type' => 'user', 'label' => 'Drupal User'),
      ),
    ),
  );
  
  return $items;
}

/**
 * Implements hook_rules_condition_info().
 */
function activecampaign_rules_rules_condition_info() {
  return array(
    'activecampaign_contact_has_tags' => array(
      'label' => t('ActiveCampaign Contact has tag(s)'),
      'parameter' => array(
        'email' => array(
          'type' => 'text',
          'label' => t('Email address of a Contact'),
          'description' => t('Email address must be of an existing activecampaign Contact'),
        ),
        'tags' => array(
          'type' => 'list<text>',
          'label' => t('Tags'),
          'options list' => 'activecampaign_get_tags_filtered',
        ),
        'operation' => array(
          'type' => 'text',
          'label' => t('Match tags'),
          'options list' => 'activecampaign_rules_condition_operations',
          'restriction' => 'input',
          'optional' => TRUE,
          'default value' => 'AND',
          'description' => t('If matching against all selected tags, the contact must have <em>all</em> the tags selected.'),
        ),
      ),
      'group' => t('ActiveCampaign'),
      'base' => 'rules_condition_activecampaign_contact_has_tag',
    ),
    'activecampaign_contact_in_list' => array(
      'label' => t('ActiveCampaign Contact in list(s)'),
      'parameter' => array(
        'email' => array(
          'type' => 'text',
          'label' => t('Email address of a Contact'),
          'description' => t('Email address must be of an existing activecampaign Contact'),
        ),
        'lists' => array(
          'type' => 'list<text>',
          'label' => t('Lists'),
          'options list' => 'activecampaign_get_lists_filtered',
        ),
        'operation' => array(
          'type' => 'text',
          'label' => t('Match lists'),
          'options list' => 'activecampaign_rules_condition_operations',
          'restriction' => 'input',
          'optional' => TRUE,
          'default value' => 'AND',
          'description' => t('If matching against all selected lists, the contact must have <em>all</em> the lists selected.'),
        ),
      ),
      'group' => t('ActiveCampaign'),
      'base' => 'rules_condition_activecampaign_contact_in_list',
    ),
  );
}

/**
 * Options list callback for the operation parameter of condition contact has tag.
 */
function activecampaign_rules_condition_operations() {
  return array(
    'AND' => t('all'),
    'OR' => t('any'),
  );
}

/**
 * Condition to check whether contact has particular tags
 */
function rules_condition_activecampaign_contact_has_tag($email, $tags, $operation = 'AND') {
  $contact = activecampaign_contact_load_email($email);
  $contacttags = $contact->tags;

  switch ($operation) {
    case 'OR':
      foreach ($tags as $tag) {
        if (in_array($tag, $contacttags)) {
          return TRUE;
        }
      }
      return FALSE;

    case 'AND':
      foreach ($tags as $tag) {
        if (!in_array($tag, $contacttags)) {
          return FALSE;
        }
      }
      return TRUE;
  }
}

/**
 * Condition to check whether contact in particular lists
 */
function rules_condition_activecampaign_contact_in_list($email, $lists, $operation = 'AND') {
  $contact = activecampaign_contact_load_email($email);
  $contactliststring = $contact->listslist;
  $contactlists = preg_split("/[-]+/", $contactliststring);

  switch ($operation) {
    case 'OR':
      foreach ($lists as $list) {
        if (in_array($list, $contactlists)) {
          return TRUE;
        }
      }
      return FALSE;

    case 'AND':
      foreach ($lists as $list) {
        if (!in_array($list, $contactlists)) {
          return FALSE;
        }
      }
      return TRUE;
  }
}

/**
 * Implements hook_rules_action_info().
 */
function activecampaign_rules_rules_action_info() {
  $actions = array();

  $actions['activecampaign_add_contact'] = array(
    'label' => t('Add a Contact by User'),
    'parameter' => array(
      'user' => array(
        'type' => 'user',
        'label' => t('The Drupal User'),
      ),
    ),
    'group' => t('activecampaign'),
    'callbacks' => array(
      'execute' => 'activecampaign_rules_add_contact',
    ),
  );

  $actions['activecampaign_rules_delete_contact'] = array(
    'label' => t('Delete a Contact'),
    'parameter' => array(
      'email' => array(
        'type' => 'text',
        'label' => t('Email address of a Contact'),
    'description' => t('Email address must be of an existing activecampaign Contact'),
      ),
    ),
    'group' => t('activecampaign'),
    'callbacks' => array(
      'execute' => 'activecampaign_rules_delete_contact',
    ),
  );

  $actions['activecampaign_add_contact_list'] = array(
    'label' => t('Add a Contact to List(s)'),
    'parameter' => array(
      'email' => array(
        'type' => 'text',
        'label' => t('Email address of a Contact'),
        'description' => t('Email address must be of an existing activecampaign Contact'),
      ),
      'activecampaign_list_id' => array(
        'type' => 'list<integer>',
        'label' => t('The ActiveCampaign List(s)'),
        'options list' => 'activecampaign_get_lists_filtered',
      ),
    ),
    'group' => t('activecampaign'),
    'callbacks' => array(
      'execute' => 'activecampaign_rules_add_to_list',
    ),
  );

  $actions['activecampaign_add_contact_tag'] = array(
    'label' => t('Add Tag(s) to a Contact'),
    'parameter' => array(
      'email' => array(
        'type' => 'text',
        'label' => t('Email address of a Contact'),
        'description' => t('Email address must be of an existing activecampaign Contact'),
      ),
      'activecampaign_tag' => array(
        'type' => 'list<text>',
        'label' => t('The ActiveCampaign Tag(s)'),
        'options list' => 'activecampaign_get_tags_filtered',
      ),
    ),
    'group' => t('activecampaign'),
    'callbacks' => array(
      'execute' => 'activecampaign_rules_add_to_tag',
    ),
  );

  $actions['activecampaign_add_contact_note_rule'] = array(
    'label' => t('Add a Note to a Contact'),
    'parameter' => array(
      'email' => array(
        'type' => 'text',
        'label' => t('Email address of a Contact'),
        'description' => t('Email address must be of an existing activecampaign Contact'),
      ),
      'activecampaign_list' => array(
        'type' => 'integer',
        'label' => t('ActiveCampaign List ID'),
        'description' => t('ActiveCampaign List ID to associate the note with. Use 0 for all lists.'),
        'optional' => TRUE,
        'default value' => '0',
      ),
      'activecampaign_note' => array(
        'type' => 'text',
        'label' => t('Note to be added to ActiveCampaign contact'),
      ),
    ),
    'group' => t('activecampaign'),
    'callbacks' => array(
      'execute' => 'activecampaign_rules_add_contact_note',
    ),
  );

  $actions['activecampaign_remove_contact_list'] = array(
    'label' => t('Unsubscribe a Contact from a List'),
    'parameter' => array(
      'email' => array(
        'type' => 'text',
        'label' => t('Email address of a Contact'),
        'description' => t('Email address must be of an existing activecampaign Contact'),
      ),
      'activecampaign_list_id' => array(
        'type' => 'list<integer>',
        'label' => t('The ActiveCampaign List(s)'),
        'options list' => 'activecampaign_get_lists_filtered',
      ),
    ),
    'group' => t('activecampaign'),
    'callbacks' => array(
      'execute' => 'activecampaign_rules_remove_from_list',
    ),
  );

  return $actions;
}

/**
 * Rules action: Add a contact
 */
function activecampaign_rules_add_contact($account) {
  activecampaign_contact_id($account);
}

/**
 * Rules action: Delete a contact
 */
function activecampaign_rules_delete_contact($email) {
  $contact = activecampaign_contact_load_email($email);
  if ($contact) {
    // Delete contact in activecampaign if one exists.
    activecampaign_contact_delete($contact->id);
  }
}

/**
 * Rules action: adds a contact to a list
 */
function activecampaign_rules_add_to_list($email, $lists) {
  $contact['email'] = $email;
  foreach ($lists as $listid => $list) {
    $contact['p['.$listid.']'] = $listid;
  }
  activecampaign_contact_sync($contact);
}

/**
 * Rules action: adds tag(s) to a contact
 */
function activecampaign_rules_add_to_tag($email, $tags) {
  $contact['email'] = $email;
  $contact['tags'] = $tags;
  activecampaign_contact_sync($contact);
}

/**
 * Rules action: Add a new contact note
 */
function activecampaign_rules_add_contact_note($email, $list, $note) {
  $contact = activecampaign_contact_load_email($email);
  if ($contact) {
    // Add note to contact if a contact with that email exists.
    activecampaign_add_contact_note($contact->id, $list, $note);
  }
}

/**
 * Rules action: unsubscribe a contact from a list
 */
function activecampaign_rules_remove_from_list($email, $lists) {
  $contact['email'] = $email;
  foreach ($lists as $listid => $list) {
    $contact['p['.$listid.']'] = $listid;
	$contact['status['.$listid.']'] = 2;
  }
  activecampaign_contact_sync($contact);
}
